@@ -136,12 +136,18 @@ static void
 thunar_folder_constructed (GObject *object)
 {
   ThunarFolder *folder = THUNAR_FOLDER (object);
+  GError       *error  = NULL;
 
-  /* add us to the folder alteration monitor */
   folder->monitor = g_file_monitor_directory (thunar_file_get_file (folder->corresponding_file),
-                                          G_FILE_MONITOR_SEND_MOVED, NULL, NULL);
+                                              G_FILE_MONITOR_WATCH_MOVES, NULL, &error);
+
   if (G_LIKELY (folder->monitor != NULL))
       g_signal_connect (folder->monitor, "changed", G_CALLBACK (thunar_folder_monitor), folder);
+  else
+    {
+      g_debug ("Could not create folder monitor: %s", error->message);
+      g_error_free (error);
+    }
 
   G_OBJECT_CLASS (thunar_folder_parent_class)->constructed (object);
 }
@@ -793,8 +799,9 @@ thunar_folder_monitor (GFileMonitor     *monitor,
                   g_object_unref (destroyed);
                 }
             }
-
-          else if (event_type == G_FILE_MONITOR_EVENT_MOVED)
+          else if (event_type == G_FILE_MONITOR_EVENT_RENAMED ||
+                   event_type == G_FILE_MONITOR_EVENT_MOVED_IN ||
+                   event_type == G_FILE_MONITOR_EVENT_MOVED_OUT)
             {
               /* destroy the old file and update the new one */
               thunar_file_destroy (lp->data);
@@ -969,6 +976,23 @@ thunar_folder_get_loading (const ThunarFolder *folder)
 
 
 
+/**
+ * thunar_folder_has_folder_monitor:
+ * @folder : a #ThunarFolder instance.
+ *
+ * Tells whether the @folder has a folder monitor running
+ *
+ * Return value: %TRUE if @folder has a folder monitor, else %FALSE.
+ **/
+gboolean
+thunar_folder_has_folder_monitor (const ThunarFolder *folder)
+{
+  _thunar_return_val_if_fail (THUNAR_IS_FOLDER (folder), FALSE);
+  return (folder->monitor != NULL);
+}
+
+
+
 /**
  * thunar_folder_reload:
  * @folder : a #ThunarFolder instance.
