@@ -49,6 +49,7 @@ enum
   PROP_0,
   PROP_ICON_THEME,
   PROP_THUMBNAIL_MODE,
+  PROP_THUMBNAIL_DRAW_FRAMES,
   PROP_THUMBNAIL_SIZE,
 };
 
@@ -107,6 +108,8 @@ struct _ThunarIconFactory
 
   ThunarThumbnailMode  thumbnail_mode;
 
+  gboolean             thumbnail_draw_frames;
+
   ThunarThumbnailSize  thumbnail_size;
 
   guint                sweep_timer_id;
@@ -186,6 +189,21 @@ thunar_icon_factory_class_init (ThunarIconFactoryClass *klass)
                                                       THUNAR_THUMBNAIL_MODE_ONLY_LOCAL,
                                                       EXO_PARAM_READWRITE));
 
+  /**
+   * ThunarIconFactory:thumbnail-draw-frames:
+   * 
+   * Whether to draw black frames around thumbnails.
+   * This looks neat, but will delay the first draw a bit.
+   * May have an impact on older systems, on folders with many pictures.
+   **/
+  g_object_class_install_property (gobject_class,
+                                   PROP_THUMBNAIL_DRAW_FRAMES,
+                                   g_param_spec_boolean ("thumbnail-draw-frames",
+                                                         "thumbnail-draw-frames",
+                                                         "thumbnail-draw-frames",
+                                                         FALSE,
+                                                         EXO_PARAM_READWRITE));
+
   /**
    * ThunarIconFactory:thumbnail-size:
    *
@@ -284,6 +302,10 @@ thunar_icon_factory_get_property (GObject    *object,
       g_value_set_enum (value, factory->thumbnail_mode);
       break;
 
+    case PROP_THUMBNAIL_DRAW_FRAMES:
+      g_value_set_boolean (value, factory->thumbnail_draw_frames);
+      break;
+
     case PROP_THUMBNAIL_SIZE:
       g_value_set_enum (value, factory->thumbnail_size);
       break;
@@ -310,6 +332,10 @@ thunar_icon_factory_set_property (GObject      *object,
       factory->thumbnail_mode = g_value_get_enum (value);
       break;
 
+    case PROP_THUMBNAIL_DRAW_FRAMES:
+      factory->thumbnail_draw_frames = g_value_get_boolean (value);
+      break;
+
     case PROP_THUMBNAIL_SIZE:
       factory->thumbnail_size = g_value_get_enum (value);
       break;
@@ -471,14 +497,15 @@ thunar_icon_factory_load_from_file (ThunarIconFactory *factory,
       width = gdk_pixbuf_get_width (pixbuf);
       height = gdk_pixbuf_get_height (pixbuf);
 
-      /* check if we want to add a frame to the image (we really don't
-       * want to do this for icons displayed in the details view).
-       */
       needs_frame = FALSE;
-      /* Disabled for 1.8.0 release, will be made optional later
-       * needs_frame = (strstr (path, G_DIR_SEPARATOR_S ".cache/thumbnails" G_DIR_SEPARATOR_S) != NULL)
-       *         && (size >= 32) && thumbnail_needs_frame (pixbuf, width, height);
-       */
+      if (factory->thumbnail_draw_frames)
+        {
+          /* check if we want to add a frame to the image (we really don't
+           * want to do this for icons displayed in the details view).
+           * */
+          needs_frame = (strstr (path, G_DIR_SEPARATOR_S ".cache/thumbnails" G_DIR_SEPARATOR_S) != NULL)
+                && (size >= 32) && thumbnail_needs_frame (pixbuf, width, height, size);
+        }
 
       /* be sure to make framed thumbnails fit into the size */
       if (G_LIKELY (needs_frame))
