@@ -324,3 +324,20 @@ thunar_view_scroll_to_file (ThunarView *view,
 }
 
 
+
+GList*
+thunar_view_get_selected_files (ThunarView *view)
+{
+  _thunar_return_val_if_fail (THUNAR_IS_VIEW (view), NULL);
+  return (*THUNAR_VIEW_GET_IFACE (view)->get_selected_files) (view);
+}
+
+
+
+void
+thunar_view_set_selected_files (ThunarView *view,
+                                GList      *path_list)
+{
+  _thunar_return_if_fail (THUNAR_IS_VIEW (view));
+  (*THUNAR_VIEW_GET_IFACE (view)->set_selected_files) (view, path_list);
+}
